      SUBROUTINE INSERTYEAR(nn,c,file,maxchar)

C     INSERTYEAR INSERTS THE LAST TWO DIGITS OF A YEAR
C     FOR THE GIVEN CHARACTER

c     nn - year (may be four digit form or two digit form)
c     c - character to replace
c     file - file name for replacement
c     maxchar - characters in file

      character*1 c
      character*(*) file
  
      n=nn
      if ( nn .lt. 200 ) n=n+1900
      call insertfor2000(n,c,file,maxchar)
      call insertnum(c,n,file,maxchar)

      return
      end
